@@ -33,7 +33,7 @@
 	IBOutlet NSTextField *trackNumberLabel;
 	IBOutlet NSTextField *genreLabel;
 	IBOutlet NSTextField *yearLabel;
-  IBOutlet NSButton *albumArtButton;
+  IBOutlet NSImageView *imageView;
 	
 	SEL writeTagSelector;
 	id writeTagTarget;
