@@ -38,6 +38,9 @@
 	uint16_t *supportedFiletypes;
 	uint16_t supportedFiletypesLength;
   BOOL createAlbumFiles;
+  BOOL uploadAlbumArt;
+  unsigned albumArtHeight;
+  unsigned albumArtWidth;
   BOOL cancelCurrentTransaction;
 	
 	NSString *deviceString;
@@ -102,9 +105,14 @@
 - (void)downloadAlbumList;
 - (Album *)addTrack:(Track *)track ToAlbumWithName:(NSString *)albumName;
 - (void)setCreateAlbumFiles:(BOOL)newCreateAlbumFiles;
+- (void)setUploadAlbumArt:(BOOL)newUploadAlbumArt;
+- (void)setAlbumArtWidth:(unsigned)newAlbumArtWidth;
+- (void)setAlbumArtHeight:(unsigned)newAlbumArtHeight;
 - (void)cancelCurrentTransaction;
 - (NJBTransactionResult *)uploadAlbumArtForTrack:(Track *)track;
 - (NJBTransactionResult *)uploadAlbumArt:(NSBitmapImageRep *)imageRep forAlbum:(Album *)album;
+- (void)runNotificationLoopWithObject:(id)obj;
+- (NJBTransactionResult *)connectWithIterator;
 
 int progress (u_int64_t sent, u_int64_t total, const char* buf, unsigned len, void *data);
 int mtp_progress (uint64_t const sent, uint64_t const total, void const * const data);
