@@ -210,6 +210,8 @@
 	NJBTransactionResult *result = [[NJBTransactionResult alloc] initWithSuccess:(playlists != nil)];
 		
 	[playlists retain];
+  
+  NSLog(@"leaving downloadPlaylists");
 		
 	return [result autorelease];
 }
@@ -219,6 +221,7 @@
  */
 - (void)fillPlaylistTrackInfo
 {
+  NSLog(@"enter fillPlaylistTrackInfo");
 	NSEnumerator *enumerator = [playlists objectEnumerator];
 	Playlist *currentPlaylist;
 	while (currentPlaylist = [enumerator nextObject])
