@@ -941,7 +941,7 @@ static guint get_track_time (gchar *path)
 unsigned int length_from_file(char *path)
 {
   mp3info *mp3info;
-  gint millisec;
+  gint millisec = 0;
   gint bitrate;
   
   // mp3_read_gain (path, track);
