@@ -10,7 +10,7 @@
 #import <zlib.h>
 #import <AppKit/NSBitmapImageRep.h>
 
-#define kTrimSetStr	@"%c%@", '\0', @" \r\n\t" //, @"\0\0"
+#define kTrimSetStr	@"%c%s", '\0', " \r\n\t" //, @"\0\0"
 
 @implementation id3V2Frame
 -(id)initFrame:(NSData *)Frame length:(int)Length frameID:(NSString *)FrameID firstflag:(char)FlagByte1 secondFlag:(char)FlagByte2 version:(int)Version
